# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['sqlfmt', 'sqlfmt.rules']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.0,<9.0', 'platformdirs>=2.4,<4.0', 'tqdm>=4.0,<5.0']

extras_require = \
{':python_version < "3.11"': ['tomli>=2.0.1,<3.0.0'],
 ':python_version < "3.8"': ['backports.cached_property>=1.0.2,<2.0.0',
                             'importlib_metadata'],
 'jinjafmt': ['black'],
 'sqlfmt-primer': ['gitpython>=3.1.24,<4.0.0']}

entry_points = \
{'console_scripts': ['sqlfmt = sqlfmt.cli:sqlfmt',
                     'sqlfmt_primer = sqlfmt_primer.primer:sqlfmt_primer']}

setup_kwargs = {
    'name': 'shandy-sqlfmt',
    'version': '0.20.0',
    'description': "sqlfmt formats your dbt SQL files so you don't have to.",
    'long_description': '# sqlfmt\n\n[![PyPI](https://img.shields.io/pypi/v/shandy-sqlfmt)](https://pypi.org/project/shandy-sqlfmt/)\n[![Downloads](https://static.pepy.tech/personalized-badge/shandy-sqlfmt?period=month&units=international_system&left_color=grey&right_color=orange&left_text=downloads/mo)](https://pepy.tech/project/shandy-sqlfmt)\n[![Test](https://github.com/tconbeer/sqlfmt/actions/workflows/test.yml/badge.svg?branch=main&event=push)](https://github.com/tconbeer/sqlfmt/actions/workflows/test.yml)\n\n![PyPI - Python Version](https://img.shields.io/pypi/pyversions/shandy-sqlfmt)\n![Runs on Linux | MacOS | Windows](https://img.shields.io/badge/runs%20on-Linux%20%7C%20MacOS%20%7C%20Windows-blue)\n\n\nsqlfmt formats your dbt SQL files so you don\'t have to. It is similar in nature to black, gofmt, \nand rustfmt (but for SQL). \n\n1. **sqlfmt promotes collaboration.** An auto-formatter makes it easier to collaborate with your team and solicit contributions from new people. You will never have to mention (or argue about) code style in code reviews again.\n2. **sqlfmt is fast.** Forget about formatting your code, and spend your time on business logic instead. sqlfmt processes hundreds of files per second and only operates on files that have changed since the last run.\n3. **sqlfmt works with Jinja.** It formats the code that users look at, and therefore doesn\'t need to know anything about what happens after the templates are rendered.\n3. **sqlfmt integrates with your workflow.** As a CLI written in Python, it\'s easy to install locally on any OS and run in CI. Plays well with dbt, pre-commit, SQLFluff, VSCode, and GitHub Actions. sqlfmt powers the dbt Cloud IDE\'s Format button.\n\nsqlfmt is not configurable, except for line length. It enforces a single style. sqlfmt maintains comments and some extra newlines, but largely ignores all indentation and line breaks in the input file.\n\nsqlfmt is not a linter. It does not parse your code into an AST; it just lexes it and tracks a small subset of tokens that impact formatting. This lets us "do one thing and do it well:" sqlfmt is very fast, and easier to maintain and extend than linters that need a full SQL grammar.\n\nFor now, sqlfmt only works on `select`, `delete`, `grant`, `revoke`, and `create function` statements (which is all you need if you use sqlfmt with a dbt project). It is being extended to additional DDL and DML. Visit [this tracking issue](https://github.com/tconbeer/sqlfmt/issues/262) for more information.\n\n## Documentation\n\nPlease visit [docs.sqlfmt.com](https://docs.sqlfmt.com) for more information on Getting Started, Integrations, the sqlfmt Style, and an API Reference. Or keep reading for an excerpt from the full docs.\n\n### Installation\n\n#### Try it first\nWant to test out sqlfmt on a query before you install it? Go to [sqlfmt.com](https://sqlfmt.com) to use the interactive, web-based version.\n\n#### Install Using pipx (recommended)\nsqlfmt is a pip-installable Python package listed on PyPI under the name `shandy-sqlfmt`. You should install it into a virtual environment, which `pipx` does automatically:\n\n```\npipx install shandy-sqlfmt\n```\n\nTo install with the jinjafmt extra (which will also install the Python code formatter, *black*):\n\n```\npipx install shandy-sqlfmt[jinjafmt]\n```\n\nFor more installation options, [read the docs](https://docs.sqlfmt.com/getting-started/installation).\n\n### Getting Started\n\n#### Other prerequisites\n**sqlfmt will not always produce the formatted output you might want.** It might even break your SQL syntax. It is **highly recommended** to only run sqlfmt on files in a version control system (like git), so that it is easy for you to revert any changes made by sqlfmt. On your first run, be sure to make a commit before running sqlfmt.\n\nThere are certain situations where sqlfmt can be considered to be in Beta, or even more mature than that. Those are:\n\n1. Using sqlfmt to format select statements for one of the major dialects (PostgresSQL, MySQL, Snowflake, BQ, Redshift).\n\n1. Using sqlfmt to format a dbt project (which may also include jinja and some minimal DDL/DML, like grants, create function, etc.) for one of the major dialects.\n\nHowever, there are other use cases where sqlfmt is very much alpha:\n\n1. Formatting some dialects that deviate from ANSI or Postgres, like T-SQL (SQLServer).\n\n1. Formatting other DDL (create table, insert, etc.) (sqlfmt attempts to be no-op on these statements as much as possible).\n\nIn these domains sqlfmt is nowhere near "feature complete" and caution is highly advised.\n\n#### Using sqlfmt\nTo list commands and options:\n\n```bash\nsqlfmt --help\n```\n\nIf you want to format all `.sql` and `.sql.jinja` files in your current working directory (and all nested directories), simply type:\n```bash\n$ sqlfmt .\n```\n\nIf you don\'t want to format the files you have on disk, you can run sqlfmt with the `--check` option. sqlfmt will exit with code 1 if the files on disk are not properly formatted:\n```bash\n$ sqlfmt --check .\n```\nIf you want to print a diff of changes that sqlfmt would make to format a file (but not update the file on disk), you can use the `--diff` option. `--diff` also exits with 1 on changes:\n```bash\n$ sqlfmt --diff .\n```\n\nFor more commands, see [the docs](https://docs.sqlfmt.com/getting-started/using-sqlfmt).\n\n#### Configuring sqlfmt using pyproject.toml\n\nAny command-line option for sqlfmt can also be set in a `pyproject.toml` file, under a `[tool.sqlfmt]` section header. Options passed at the command line will override the settings in the config file. [See the docs](https://docs.sqlfmt.com/getting-started/configuring-sqlfmt) for more information.\n\n#### The jinjafmt extra\n\nsqlfmt loves properly-formatted jinja, too.\n\n[See the docs](https://docs.sqlfmt.com/getting-started/formatting-jinja) for more information about using the `jinjafmt` extra or disabling jinja formatting.\n\n### Using sqlfmt with different SQL dialects\n\nsqlfmt\'s rules are simple, which means it does not have to parse every single token in your query. This allows nearly all SQL dialects to be formatted using sqlfmt\'s default "polyglot" dialect, which requires no configuration.\n\nThe exception to this is [ClickHouse](https://docs.sqlfmt.com/dialects/#clickhouse), which is case-sensitive where other dialects are not. To prevent the lowercasing of function names, database identifiers, and aliases, use the `--dialect clickhouse` option when running sqlfmt. For example,\n\n```bash\n$ sqlfmt . --dialect clickhouse\n```\n\nThis can also be configured using the `pyproject.toml` file:\n\n```toml\n[tool.sqlfmt]\ndialect = "clickhouse"\n```\n\nNote that with this option, sqlfmt will not lowercase **most** non-reserved keywords, even common ones like `sum` or `count`. See (and please join) [this discussion](https://github.com/tconbeer/sqlfmt/discussions/229) for more on this topic.\n\n### Integrations\n\nsqlfmt plays nicely with other analytics engineering tools. For more information, [see the docs](https://docs.sqlfmt.com/category/integrations).\n\n#### dbt\n\nsqlfmt was built for dbt, so only [minimal configuration](https://docs.sqlfmt.com/integrations/dbt) is required. We recommend excluding your `target` and `dbt_packages` directories from formatting. You can do this with the command-line `--exclude` option, or by setting `exclude` in your `pyproject.toml` file:\n\n```toml\n[tool.sqlfmt]\nexclude=["target/**/*", "dbt_packages/**/*"]\n```\n\n#### Other Integrations\n\nConfig for other integrations is detailed in the docs linked below:\n\n- [pre-commit](https://docs.sqlfmt.com/integrations/pre-commit)\n- [SQLFluff](https://docs.sqlfmt.com/integrations/sqlfluff)\n- [VSCode](https://docs.sqlfmt.com/integrations/vs-code)\n\n\n## The sqlfmt style\nThe only thing you can configure with sqlfmt is the desired line length of the formatted file. You can do this with the `--line-length` or `-l` options. The default is 88.\n\nsqlfmt borrows elements from well-accepted styles from other programming languages. It places opening brackets on the same line as preceding function names (like *black* for python and *1TBS* for C). It indents closing brackets to the same depth as the opening bracket (this is extended to statements that must be closed, like `case` and `end`).\n\nThe sqlfmt style is as simple as possible, with little-to-no special-casing of formatting concerns. While at first blush, this may not create a format that is as "nice" or "expressive" as hand-crafted indentation, over time, as you grow accustomed to the style, formatting becomes transparent and the consistency will allow you to jump between files, projects, and even companies much faster.\n\n[Read More](https://docs.sqlfmt.com/style/)\n\n### Why lowercase?\nBecause SQL is code! But there are [other good reasons too](https://docs.sqlfmt.com/style/#why-lowercase).\n\n### Why trailing commas?\nUsing trailing commas follows the convention of every other written language and programming language. [But wait, there\'s more.](https://docs.sqlfmt.com/style/#why-trailing-commas)\n\n## Contributing\n\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)\n[![Maintainability](https://api.codeclimate.com/v1/badges/8928f6662a67b8eaf092/maintainability)](https://codeclimate.com/github/tconbeer/sqlfmt/maintainability)\n[![Test Coverage](https://api.codeclimate.com/v1/badges/8928f6662a67b8eaf092/test_coverage)](https://codeclimate.com/github/tconbeer/sqlfmt/test_coverage)\n\n### Providing Feedback\n\nWe\'d love to hear from you! [Open an Issue](https://github.com/tconbeer/sqlfmt/issues/new/choose) to request new features, report bad formatting, or say hello.\n\n### Setting up Your Dev Environment and Running Tests\n\n1. Install [Poetry](https://python-poetry.org/docs/#installation) v1.2 or higher if you don\'t have it already. You may also need or want pyenv, make, and gcc. A complete setup from a fresh install of Ubuntu can be found [here](https://github.com/tconbeer/linux_setup).\n1. Clone this repo into a directory (let\'s call it `sqlfmt`), then `cd sqlfmt`.\n1. Use `poetry install --all-extras --sync` to install the project (editable) and its dependencies (including the `jinjafmt` and `sqlfmt_primer` extras) into a new virtual env.\n1. Use `poetry shell` to spawn a subshell.\n1. Type `make` to run all tests and linters, or run `pytest`, `black`, `flake8`, `isort`, and `mypy` individually.\n\n### Updating primer repos to reflect formatting changes\n\n1. Make sure all changes are committed to sqlfmt.\n1. Check out `main` in the repo and make sure you `pull` changes locally.\n1. Check out the `unformatted` tag in the repo with `git checkout -b chore/apply-abc123 unformatted` where `abc123` is the hash of the most recent sqlfmt commit (from 1).\n1. Run sqlfmt against the working tree, then `git add .` and `git commit -m "chore: apply sqlfmt abc123"`.\n1. We will have conflicts with main that we want to ignore, so merge main into this branch, ignoring anything on main: `git merge -s ours main`.\n1. Push and open a PR; squash and merge. Grab the commit SHA.\n1. Paste the commit SHA as a ref into `primer.py`.\n1. Run `sqlfmt_primer -k` to clear the cache, then update the stats in `primer.py` to match the results.\n',
    'author': 'Ted Conbeer',
    'author_email': 'ted@shandy.io',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://sqlfmt.com',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
